# LOBSTER

The **L**ightweight **O**pen **B**MW **S**oftware **T**raceability
**E**vidence **R**eport allows you to demonstrate software traceability
and requirements coverage, which is essential for meeting standards
such as ISO 26262.

This package contains a tool to interface with the proprietary
requirements management tool
[Codebeamer](https://intland.com/codebeamer).

## Tools

* `lobster-codebeamer`: Extrat requirements from codebeamer.

## Usage

There are two ways you can use this tool:

* Download all requirements mentioned by another lobster trace (this
  way you do not get a completeness check) (using `--import-tagged`)

* Download all requirements generated by a saved codebeamer query
  (using `--import-query`)

## Limitations

The key limitation is item text, which is currently not
imported. However we do plan to also import item text eventually.

## Copyright & License information

The copyright holder of LOBSTER is the Bayerische Motoren Werke
Aktiengesellschaft (BMW AG), and LOBSTER is published under the [GNU
Affero General Public License, Version 3](../LICENSE.md).

This tool has no actual dependency on, or with, Codebeamer. It just
talks the API as described here: https://codebeamer.com/cb/wiki/117612
